.. cvasl documentation master

cvasl documentation
=======================

Here is some general information about the cvasl package. We are working on
documentation for programmers and medical professionals with some coding
experience. 


The API Documentation / Guide
-----------------------------

If you are looking for information on a specific function, class, or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules
   developers
   medical-professionals

Developer's Guide
-----------------

:doc:`Developer's Guide <../developers>`

Medical Professionals Documentation
-----------------------------------

:doc:`Medical Professionals Documentation <../medical-professionals>`


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
